Meteorology
===========

.. autoclass:: physics.environment.meteorology.BaseMeteorology
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: physics.environment.meteorology.IrradiantMeteorology
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: physics.environment.meteorology.CloudedMeteorology
   :members:
   :undoc-members:
   :show-inheritance: